intelmq.bots.outputs.tcp package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.outputs.tcp package

## Submodules

## intelmq.bots.outputs.tcp.output module

For intelmq collectors on the other side we can expect the “ok” sent back. Otherwise, for filebeat and other we can’t do that. As this was the previous behavior, that’s the default. https://github.com/certtools/intelmq/issues/1385

intelmq.bots.outputs.tcp.output.BOT

  alias of `intelmq.bots.outputs.tcp.output.TCPOutputBot`

class intelmq.bots.outputs.tcp.output.TCPOutputBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.OutputBot`

  Send events to a TCP server as Splunk, ElasticSearch or another IntelMQ etc

  connect()
  counterpart_is_intelmq: bool = True
  hierarchical_output: bool = False
  init()
  ip: str = None
  port: int = None
  process()
  recvall(conn, n)
  separator: str = None

## Module contents